document.addEventListener('DOMContentLoaded', () => {
  const searchInput = document.getElementById('searchInput');
  const searchButton = document.getElementById('searchButton');
  const gamesGrid = document.querySelector('.games-grid');
  
  // Sample game data (in production, this would come from a backend)
  const games = [
    { name: 'Catan', players: '3-4', time: 'medium', difficulty: 'medium' },
    { name: 'Monopoly', players: '2-8', time: 'long', difficulty: 'easy' },
    { name: 'Pandemic', players: '2-4', time: 'medium', difficulty: 'hard' }
  ];

  const createGameCard = (game) => {
    const card = document.createElement('div');
    card.className = 'game-card';
    card.style.backgroundColor = 'white';
    card.style.padding = '1.5rem';
    card.style.borderRadius = '8px';
    card.style.boxShadow = 'var(--shadow)';
    card.style.transition = 'transform 0.3s';
    
    card.innerHTML = `
      <h3>${game.name}</h3>
      <p>Liczba graczy: ${game.players}</p>
      <p>Czas gry: ${game.time}</p>
      <p>Poziom trudności: ${game.difficulty}</p>
    `;

    card.addEventListener('mouseover', () => {
      card.style.transform = 'translateY(-5px)';
    });

    card.addEventListener('mouseout', () => {
      card.style.transform = 'translateY(0)';
    });

    return card;
  };

  const filterGames = () => {
    const searchTerm = searchInput.value.toLowerCase();
    const playerCount = document.getElementById('playerCount').value;
    const gameTime = document.getElementById('gameTime').value;
    const difficulty = document.getElementById('difficulty').value;

    const filteredGames = games.filter(game => {
      return game.name.toLowerCase().includes(searchTerm) &&
        (!playerCount || game.players.includes(playerCount)) &&
        (!gameTime || game.time === gameTime) &&
        (!difficulty || game.difficulty === difficulty);
    });

    gamesGrid.innerHTML = '';
    filteredGames.forEach(game => {
      gamesGrid.appendChild(createGameCard(game));
    });
  };

  searchButton.addEventListener('click', filterGames);
  searchInput.addEventListener('keypress', (e) => {
    if (e.key === 'Enter') {
      filterGames();
    }
  });

  // Initialize with all games
  games.forEach(game => {
    gamesGrid.appendChild(createGameCard(game));
  });
});
